/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { SubscriptionPlan } from "../models/SubscriptionPlan";
import type { UserAccountListItem } from "../models/UserAccountListItem";
import { request as __request } from "../core/request";

export class AdminService {
  /**
   * Lists all the accounts for an email address.
   * @param email
   * @returns UserAccountListItem Success.
   * @throws ApiError
   */
  public static async listUserAccounts(email: EmailAddress): Promise<Array<UserAccountListItem>> {
    const result = await __request({
      method: "GET",
      path: `/v1/admin/accounts`,
      query: {
        email: email
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Disables the user's access, deletes their files, and purges the CDN.
   * @param accountId
   * @returns any Success.
   * @throws ApiError
   */
  public static async wipeAccount(accountId: AccountId): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/admin/accounts/${accountId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Set account limits.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setAccountLimits(accountId: AccountId, requestBody: SubscriptionPlan): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/admin/accounts/${accountId}/limits`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
